@@ -1,9 +1,18 @@
+#define __KERNEL__
 #include <sys/types.h>
+#include <termios.h>
+#include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <stdio.h>
-#include <fcntl.h>
 #include <string.h>
+#include <pwd.h>
+#include <errno.h>
+#include <ctype.h>
+#include <time.h>
+#include <sys/ioctl.h>
+#include <linux/sched.h>
+#include <linux/ptrace.h>
+#include <fcntl.h>
 #include <getopt.h>
 #include "ps.h"
 #include "psdata.h"
