@@ -2,10 +2,21 @@
  * devname.c
  *
  */
-
+#define __KERNEL__
+#include <sys/types.h>
+#include <termios.h>
 #include <stdio.h>
-#include <limits.h>
+#include <unistd.h>
+#include <stdlib.h>
 #include <string.h>
+#include <pwd.h>
+#include <errno.h>
+#include <ctype.h>
+#include <time.h>
+#include <sys/ioctl.h>
+#include <linux/sched.h>
+#include <linux/ptrace.h>
+#include <limits.h>
 #include <sys/stat.h>
 #include <sys/sysmacros.h>
 #include "ps.h"
