@@ -5,6 +5,7 @@
  * Copyright (c) 1992 Branko Lankester
  */
 
+#define __KERNEL__
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -153,7 +154,6 @@ main(int argc, char *argv[])
 	    if (!all)
 		show_inode(task, task->fs->root, -1);
 	    show_inode(task, task->fs->pwd, -2);
-	    show_inode(task, task->executable, -3);
 	    for (vmm = task->mm->mmap; vmm; vmm = vm.vm_next) {
 		kmemread(&vm, (unsigned long) vmm, sizeof vm);
 		if (vm.vm_inode)
@@ -367,14 +367,13 @@ lookup_filename(int ino, int dev)
 #include <linux/net.h>
 #include <netinet/in.h>
 #include <sys/un.h>
-#include <linux/ddi.h>
 #include <linux/timer.h>
 #include <linux/ip.h>
 #include <linux/tcp.h>
 #include <linux/netdevice.h>
 #include <linux/skbuff.h>
-#include <net/inet/inet.h>
-#include <net/inet/dev.h>
+#include <linux/inet.h>
+#include <linux/netdevice.h>
 #include <net/inet/protocol.h>
 #include <net/inet/sock.h>
 #include <net/inet/ip.h>
