@@ -7,9 +7,20 @@
  * compile with -p).
  */
 
+#define __KERNEL__
+#include <sys/types.h>
+#include <termios.h>
 #include <stdio.h>
+#include <unistd.h>
 #include <stdlib.h>
-#include <linux/mm.h>
+#include <string.h>
+#include <pwd.h>
+#include <errno.h>
+#include <ctype.h>
+#include <time.h>
+#include <sys/ioctl.h>
+#include <linux/sched.h>
+#include <linux/ptrace.h>
 #include <sys/stat.h>
 #include "ps.h"
 #include "psdata.h"
