@@ -83,7 +83,7 @@ static char sccsid[] = "@(#)w.c	5.29 (Berkeley) 4/23/91";
 #define	_PATH_DEV	"/dev/"
 #endif
 #ifndef	_PATH_UTMP
-#define	_PATH_UTMP	"/etc/utmp"
+#define	_PATH_UTMP	"/var/adm/utmp"
 #endif
 
 char	*program;
@@ -442,11 +442,11 @@ prttime(time_t tim, char *tail)
 {
 
 	if (tim >= 60) {
-		printf("%3d:", tim/60);
+		printf("%3ld:", (long) tim/60);
 		tim %= 60;
-		printf("%02d", tim);
+		printf("%02ld", (long) tim);
 	} else if (tim > 0)
-		printf("    %2d", tim);
+		printf("    %2ld", (long) tim);
 	else
 		printf("      ");
 	printf("%s", tail);
