@@ -5,6 +5,7 @@
  *
  */
 
+#define __KERNEL__
 #include <stdio.h>
 #include <string.h>
 #include <sys/sysmacros.h>
@@ -53,7 +54,7 @@ wchan(reg_t ebp, reg_t *stack, int numeric)
     int bp;
     static char buf[16], *p;
 
-    bp = (ebp & PAGE_MASK) >> 2;
+    bp = (ebp & ~PAGE_MASK) >> 2;
     eip = stack[bp + 1];
     p = find_func(eip);
     if (strcmp(p, "_sleep_on") == 0 ||
