@@ -12,16 +12,24 @@
  * Copyright (c) 1992 Branko Lankester
  */
 
+#define __KERNEL__
 #include <sys/types.h>
+#include <termios.h>
+#include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <stdio.h>
 #include <string.h>
+#include <pwd.h>
+#include <errno.h>
+#include <ctype.h>
+#include <time.h>
+#include <sys/ioctl.h>
+#include <linux/sched.h>
+#include <linux/ptrace.h>
 #include <termios.h>
 #include <signal.h>
 #include <fcntl.h>
 #include <sys/stat.h>
-#include <sys/ioctl.h>
 #include <sys/sysmacros.h>
 #include <setjmp.h>
 #include "ps.h"
