@@ -47,6 +47,8 @@ static char sccsid[] = "@(#)w.c	5.29 (Berkeley) 4/23/91";
  * This program is similar to the systat command on Tenex/Tops 10/20
  *
  */
+
+#define __KERNEL__
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -57,7 +59,6 @@ static char sccsid[] = "@(#)w.c	5.29 (Berkeley) 4/23/91";
 #include <stdio.h>
 #include <getopt.h>
 #include <stdarg.h>
-#include <sys/param.h>
 #include <sys/time.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
